@@ -17,6 +17,12 @@
 
 namespace SFCGAL::algorithm {
 
+// ----------------------------------------------------------------------------------
+// -- private interface
+// ----------------------------------------------------------------------------------
+/// @{
+/// @privatesection
+
 struct EmptyPrimitive {};
 
 enum PrimitiveType {
@@ -49,7 +55,7 @@ struct Segment_d : detail::Segment_d<Dim>::Type {
   }
 
   template <class OutputIterator>
-  [[nodiscard]] [[nodiscard]] auto
+  [[nodiscard]] auto
   pieces(OutputIterator out) const -> OutputIterator
   {
     PointVector points(1, this->source());
@@ -80,7 +86,7 @@ struct Segment_d : detail::Segment_d<Dim>::Type {
   pieces() const -> SegmentVector
   {
     SegmentVector result;
-    this->pieces(std::back_inserter(result));
+    (void)this->pieces(std::back_inserter(result));
     return result;
   }
 
@@ -94,7 +100,7 @@ struct Surface_d {};
 
 template <>
 struct Surface_d<3> : Triangle_3 {
-  using PointVector   = std::vector<algorithm::Point_2>;
+  using PointVector   = std::vector<SFCGAL::Point_2>;
   using SegmentVector = std::vector<Segment_2>;
   using SurfaceVector = std::vector<PointVector>;
 
@@ -104,17 +110,16 @@ struct Surface_d<3> : Triangle_3 {
   }
 
   void
-  splitAt(const algorithm::Point_3 &p)
+  splitAt(const SFCGAL::Point_3 &p)
   {
     //@note this is a degenerated segment, but works anyway
-    _split.push_back(Segment_2(_plane.to_2d(p), _plane.to_2d(p)));
+    _split.emplace_back(_plane.to_2d(p), _plane.to_2d(p));
   }
 
   void
   splitAt(const Segment_3 &s)
   {
-    _split.push_back(
-        Segment_2(_plane.to_2d(s.source()), _plane.to_2d(s.target())));
+    _split.emplace_back(_plane.to_2d(s.source()), _plane.to_2d(s.target()));
   }
 
   template <typename Point3Iterator>
@@ -138,12 +143,12 @@ struct Surface_d<3> : Triangle_3 {
   void
   splitAt(const Triangle_3 &t)
   {
-    const algorithm::Point_3 v[3] = {t.vertex(0), t.vertex(1), t.vertex(2)};
+    const SFCGAL::Point_3 v[3] = {t.vertex(0), t.vertex(1), t.vertex(2)};
     this->splitAt(v, v + 3);
   }
 
   void
-  splitAt(const std::vector<algorithm::Point_3> &p)
+  splitAt(const std::vector<SFCGAL::Point_3> &p)
   { // polygon with unclosed ring
     this->splitAt(p.begin(), p.end());
   }
@@ -167,7 +172,7 @@ struct Surface_d<3> : Triangle_3 {
   }
 
   void
-  remove(const std::vector<algorithm::Point_3> &p)
+  remove(const std::vector<SFCGAL::Point_3> &p)
   {
     this->remove(p.begin(), p.end());
   }
@@ -175,7 +180,7 @@ struct Surface_d<3> : Triangle_3 {
   void
   remove(const Triangle_3 &t)
   {
-    const algorithm::Point_3 v[3] = {t.vertex(0), t.vertex(1), t.vertex(2)};
+    const SFCGAL::Point_3 v[3] = {t.vertex(0), t.vertex(1), t.vertex(2)};
     this->remove(v, v + 3);
   }
 
@@ -214,7 +219,7 @@ struct Surface_d<3> : Triangle_3 {
       }
 
       for (auto &line : lines) {
-        line.pieces(std::back_inserter(filtered));
+        (void)line.pieces(std::back_inserter(filtered));
       }
     }
 
@@ -267,18 +272,18 @@ struct Surface_d<3> : Triangle_3 {
   }
 
 private:
-  algorithm::Plane_3 _plane;
-  SegmentVector      _split;
-  SurfaceVector      _remove;
+  SFCGAL::Plane_3 _plane;
+  SegmentVector   _split;
+  SurfaceVector   _remove;
 };
 
 template <>
-struct Surface_d<2> : PolygonWH_2 {
+struct Surface_d<2> : Polygon_with_holes_2 {
   using PointVector   = std::vector<Point_2>;
   using SegmentVector = std::vector<Segment_2>;
   using SurfaceVector = std::vector<PointVector>;
 
-  Surface_d(const PolygonWH_2 &s) : PolygonWH_2(s) {}
+  Surface_d(const Polygon_with_holes_2 &s) : Polygon_with_holes_2(s) {}
 
   void
   splitAt(const Segment_2 &s)
@@ -293,9 +298,9 @@ struct Surface_d<2> : PolygonWH_2 {
   }
 
   [[nodiscard]] auto
-  pieces() const -> std::vector<PolygonWH_2>
+  pieces() const -> std::vector<Polygon_with_holes_2>
   {
-    std::vector<PolygonWH_2> res;
+    std::vector<Polygon_with_holes_2> res;
     fix_cgal_valid_polygon(*this, std::back_inserter(res));
     return res;
   }
@@ -333,7 +338,7 @@ class Handle {
     }
 
     template <class T>
-    inline auto
+    auto
     as() -> T &
     {
       return boost::get<T &>(*this);
@@ -384,7 +389,7 @@ public:
   }
 
   void
-  swap(Handle &other)
+  swap(Handle &other) noexcept
   {
     (*_p)->_observers.erase(_p);
     (*other._p)->_observers.erase(other._p);
@@ -770,7 +775,7 @@ union_segment_volume(Handle<3> a, Handle<3> b)
 void
 union_surface_surface(Handle<2> a, Handle<2> b)
 {
-  PolygonWH_2 res;
+  Polygon_with_holes_2 res;
 
   if (CGAL::join(fix_sfs_valid_polygon(a.asSurface()),
                  fix_sfs_valid_polygon(b.asSurface()), res)) {
@@ -1038,6 +1043,13 @@ union_(const Geometry &ga, const Geometry &gb) -> std::unique_ptr<Geometry>
   return result;
 }
 
+/// @} end of private section
+
+// ----------------------------------------------------------------------------------
+// -- public interface
+// ----------------------------------------------------------------------------------
+/// @publicsection
+
 auto
 union3D(const Geometry &ga, const Geometry &gb, NoValidityCheck /*unused*/)
     -> std::unique_ptr<Geometry>
@@ -1065,6 +1077,7 @@ union3D(const Geometry &ga, const Geometry &gb) -> std::unique_ptr<Geometry>
   return result;
 }
 
+/// @private
 void
 handleLeakTest()
 {
